@@ -389,12 +389,11 @@ void KMouthApp::slotFileQuit()
     saveOptions();
     // close the first window, the list makes the next one the first again.
     // This ensures that queryClose() is called on each window to ask for closing
-    KMainWindow* w;
     if (!memberList().isEmpty()) {
         for (int i = 0; i < memberList().size(); ++i) {
             // only close the window if the closeEvent is accepted. If the user presses Cancel on the saveModified() dialog,
             // the window and the application stay open.
-            w = memberList().at(i);
+            KMainWindow* w = memberList().at(i);
             if (!w->close())
                 break;
 #ifdef __GNUC__
