@@ -37,86 +37,37 @@ namespace WordList
 {
 void addWords(WordMap &map, const QString &line);
 
-XMLParser::XMLParser()
+XMLReader::XMLReader()
 {
 }
 
-XMLParser::~XMLParser()
+XMLReader::~XMLReader()
 {
 }
 
-bool XMLParser::warning(const QXmlParseException &)
+bool XMLReader::read(QIODevice *device)
 {
-    return false;
-}
+    xml.setDevice(device);
 
-bool XMLParser::error(const QXmlParseException &)
-{
-    return false;
-}
+    list.clear();
 
-bool XMLParser::fatalError(const QXmlParseException &)
-{
-    return false;
-}
-
-QString XMLParser::errorString() const
-{
-    return QLatin1String("");
-}
-
-bool XMLParser::startDocument()
-{
-    text.clear();
-    return true;
-}
-
-bool XMLParser::startElement(const QString &, const QString &,
-                             const QString &,
-                             const QXmlAttributes &)
-{
-    if (!text.isNull() && !text.isEmpty()) {
-        addWords(list, text);
-        text.clear();
+    while (xml.readNextStartElement()) {
+        const QString *word = xml.name().string();
+        addWords(list, *word);
     }
-    return true;
+
+    return !xml.error();
 }
 
-bool XMLParser::characters(const QString &ch)
+QString XMLReader::errorString() const
 {
-    text += ch;
-    return true;
+    return QLatin1String("%1\nLine %2, column %3")
+            .arg(xml.errorString())
+            .arg(xml.lineNumber())
+            .arg(xml.columnNumber());
 }
 
-bool XMLParser::ignorableWhitespace(const QString &)
-{
-    if (!text.isNull() && !text.isEmpty()) {
-        addWords(list, text);
-        text.clear();
-    }
-    return true;
-}
-
-bool XMLParser::endElement(const QString &, const QString &,
-                           const QString &)
-{
-    if (!text.isNull() && !text.isEmpty()) {
-        addWords(list, text);
-        text.clear();
-    }
-    return true;
-}
-
-bool XMLParser::endDocument()
-{
-    if (!text.isNull() && !text.isEmpty()) {
-        addWords(list, text);
-        text.clear();
-    }
-    return true;
-}
-
-WordMap XMLParser::getList()
+WordMap XMLReader::getList()
 {
     return list;
 }
@@ -180,15 +131,10 @@ void addWords(WordMap &map, const WordMap &add)
 void addWordsFromFile(WordMap &map, const QString &filename, QTextCodec *codec)
 {
     QFile xmlfile(filename);
-    QXmlInputSource source(&xmlfile);
-    XMLParser parser;
-    QXmlSimpleReader reader;
-    reader.setFeature(QStringLiteral("http://qt-project.org/xml/features/report-start-end-entity"), true);
-    reader.setContentHandler(&parser);
+    XMLReader reader;
 
-    WordMap words;
-    if (reader.parse(source)) // try to load the file as an xml-file
-        addWords(map, parser.getList());
+    if (reader.read(&xmlfile)) // try to load the file as an xml-file
+        addWords(map, reader.getList());
     else {
         QFile wpdfile(filename);
         if (wpdfile.open(QIODevice::ReadOnly)) {
@@ -196,8 +142,8 @@ void addWordsFromFile(WordMap &map, const QString &filename, QTextCodec *codec)
             stream.setCodec("UTF-8");
 
             if (!stream.atEnd()) {
-                QString s = stream.readLine();
-                if (s == QLatin1String("WPDictFile")) {   // Contains the file a weighted word list?
+                QString line = stream.readLine();
+                if (line == QLatin1String("WPDictFile")) {   // Contains the file a weighted word list?
                     // We can assume that weighted word lists are always UTF8 coded.
                     while (!stream.atEnd()) {
                         QString s = stream.readLine();
@@ -216,11 +162,11 @@ void addWordsFromFile(WordMap &map, const QString &filename, QTextCodec *codec)
                 } else { // Count the words in an ordinary text file
                     QFile file(filename);
                     if (file.open(QIODevice::ReadOnly)) {
-                        QTextStream stream(&file);
+                        QTextStream plainstream(&file);
                         Q_ASSERT(codec != nullptr);
-                        stream.setCodec(codec);
-                        while (!stream.atEnd())
-                            addWords(map, stream.readLine());
+                        plainstream.setCodec(codec);
+                        while (!plainstream.atEnd())
+                            addWords(map, plainstream.readLine());
                     }
                 }
             }
@@ -378,7 +324,6 @@ typedef QMap<QChar, AffList>  AffMap;
  */
 void loadAffFile(const QString &filename, AffMap &prefixes, AffMap &suffixes)
 {
-    bool cross = false;
 
     QFile afile(filename);
     if (afile.open(QIODevice::ReadOnly)) {
@@ -387,6 +332,7 @@ void loadAffFile(const QString &filename, AffMap &prefixes, AffMap &suffixes)
             QString s = stream.readLine();
             QStringList fields = s.split(QRegularExpression(QStringLiteral("\\s")));
 
+            bool cross = false;
             if (fields.count() == 4) {
                 cross = (fields[2] == QLatin1String("Y"));
             } else {
@@ -526,13 +472,13 @@ WordMap spellCheck(WordMap map, const QString &dictionary, QProgressDialog *pdlg
         pdlg->setMaximum(100);
         pdlg->setValue(0);
         qApp->processEvents(QEventLoop::AllEvents, 20);
-        int progress = 0;
-        int steps = 0;
-        int percent = 0;
 
         QFile dfile(dictionary);
         if (dfile.open(QIODevice::ReadOnly)) {
             QTextStream stream(&dfile);
+            int progress = 0;
+            int steps = 0;
+            int percent = 0;
 
             if (!stream.atEnd()) {
                 QString s = stream.readLine(); // Number of words
